@@ -19,8 +19,8 @@
 #ifndef KDED_SERIALIZER_H
 #define KDED_SERIALIZER_H
 
-#include <QtCore/QObject>
-#include <QtCore/QVariantMap>
+#include <QObject>
+#include <QVariantMap>
 
 #include <kscreen/config.h>
 
@@ -31,7 +31,8 @@ class Serializer
         static bool configExists(const KScreen::ConfigPtr &config);
         static bool configExists(const QString& id);
         static KScreen::ConfigPtr config(const KScreen::ConfigPtr &currentConfig, const QString& id);
-        static bool saveConfig(const KScreen::ConfigPtr &config);
+        static bool saveConfig(const KScreen::ConfigPtr &config, const QString &configId);
+        static void removeConfig(const QString &id);
 
         static KScreen::OutputPtr findOutput(const KScreen::ConfigPtr &config, const QVariantMap &info);
         static QString outputId(const KScreen::OutputPtr &output);
